import { type AugmentedProvider, type Provider } from "@saberhq/solana-contrib";
import { type Keypair, type PublicKey, type Signer } from "@solana/web3.js";
import type { CreateAirdropArgs, CreateDistributorArgs, MerkleDistributorProgram, PendingDistributor } from "./types";
import { MerkleDistributorWrapper } from "./wrapper";
export declare class MerkleDistributorSDK {
    readonly provider: AugmentedProvider;
    readonly program: MerkleDistributorProgram;
    constructor(provider: AugmentedProvider, program: MerkleDistributorProgram);
    withSigner(signer: Signer): MerkleDistributorSDK;
    static new(rpcURL: string, keypair: Keypair): MerkleDistributorSDK;
    /**
     * Loads the SDK.
     * @returns {MerkleDistributorSDK}
     */
    static load({ provider, }: {
        provider: Provider;
    }): MerkleDistributorSDK;
    /**
     * Load an existing merkle distributor.
     * @returns {MerkleDistributorWrapper}
     */
    loadDistributor(key: PublicKey): Promise<MerkleDistributorWrapper>;
    /**
     * Create a merkle distributor.
     * @returns {PendingDistributor}
     */
    createDistributor(args: Omit<CreateDistributorArgs, "sdk">): Promise<PendingDistributor>;
    createMerkleAirdrop(args: Omit<CreateAirdropArgs, "sdk">): Promise<PendingDistributor>;
}
//# sourceMappingURL=sdk.d.ts.map