import { newProgram } from "@saberhq/anchor-contrib";
import { SignerWallet, SingleConnectionBroadcaster, SolanaProvider, } from "@saberhq/solana-contrib";
import { SolanaAugmentedProvider } from "@saberhq/solana-contrib";
import { Connection, } from "@solana/web3.js";
import { PROGRAM_ID } from "./constants";
import { MerkleDistributorJSON } from "./idls/merkle_distributor";
import { MerkleDistributorWrapper } from "./wrapper";
export class MerkleDistributorSDK {
    constructor(provider, program) {
        this.provider = provider;
        this.program = program;
    }
    withSigner(signer) {
        return MerkleDistributorSDK.load({
            provider: this.provider.withSigner(signer),
        });
    }
    static new(rpcURL, keypair) {
        const connection = new Connection(rpcURL);
        const provider = new SolanaProvider(connection, new SingleConnectionBroadcaster(connection), new SignerWallet(keypair));
        return MerkleDistributorSDK.load({ provider });
    }
    /**
     * Loads the SDK.
     * @returns {MerkleDistributorSDK}
     */
    static load({ provider, }) {
        const aug = new SolanaAugmentedProvider(provider);
        return new MerkleDistributorSDK(aug, newProgram(MerkleDistributorJSON, PROGRAM_ID, aug));
    }
    /**
     * Load an existing merkle distributor.
     * @returns {MerkleDistributorWrapper}
     */
    async loadDistributor(key) {
        return await MerkleDistributorWrapper.load(this, key);
    }
    /**
     * Create a merkle distributor.
     * @returns {PendingDistributor}
     */
    async createDistributor(args) {
        return await MerkleDistributorWrapper.createDistributor({
            sdk: this,
            ...args,
        });
    }
    async createMerkleAirdrop(args) {
        return await MerkleDistributorWrapper.createMerkleAirdrop({
            sdk: this,
            ...args,
        });
    }
}
//# sourceMappingURL=sdk.js.map